//
//  AppDelegate.m
//  Alexis
//
//  Created by Geronimo on 25/11/15.
//  Copyright © 2015 Foxcom. All rights reserved.
//

#import "AppDelegate.h"
#import "sqlite3.h"

@interface AppDelegate ()

@end

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    
    //[self deleteDb];
    
    // existuje DB? pokud ne, vytvorime ji
    if ([self checkDbExists])
    {
        if (![self checkDbVersion]) {
            [self deleteDb];
            [self createDb];
        }
    }
    else
    {
        [self createDb];
    }
    
    return YES;
}

- (void)applicationWillResignActive:(UIApplication *)application {
    // Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
    // Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
}

- (void)applicationDidEnterBackground:(UIApplication *)application {
    // Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later.
    // If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
}

- (void)applicationWillEnterForeground:(UIApplication *)application {
    // Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
}

- (void)applicationDidBecomeActive:(UIApplication *)application {
    // Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
}

- (void)applicationWillTerminate:(UIApplication *)application {
    // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
}

- (BOOL)addSkipBackupAttributeToItemAtURL:(NSURL *)URL
{
    NSError *error = nil;
    [URL setResourceValue:[NSNumber numberWithBool:YES] forKey:NSURLIsExcludedFromBackupKey error:&error];
    return error == nil;
}

- (BOOL)checkDbExists
{
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    BOOL success;
    
    NSFileManager *fileManager = [NSFileManager defaultManager];
    
    success = [fileManager fileExistsAtPath:databasePath];
    
    if(success)
    {
        NSLog(@"DB exists");
        return YES;
    }
    else
    {
        NSLog(@"DB does not exists");
        return NO;
    }
}

- (BOOL)checkDbVersion
{
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    BOOL success;
    success = NO;
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT 1 FROM info WHERE key = 'version' AND value = '%@'", databaseVersion];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                success = YES;
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return success;
}

- (void)createDb
{
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *dir = [paths objectAtIndex:0];
    
    
    // create directory(if not exists) and set skipBackupAttribute to it
    if ( ! [[NSFileManager defaultManager] fileExistsAtPath:dir] )
        [[NSFileManager defaultManager] createDirectoryAtPath:dir withIntermediateDirectories:YES attributes:nil error:nil];
    NSURL *db_url = [NSURL fileURLWithPath:dir];
    [self addSkipBackupAttributeToItemAtURL:db_url];
    
    NSString *databasePath = [dir stringByAppendingPathComponent:databaseName];
    
    // vytvoreni datove struktury DB
    
    //create tables
    sqlite3 *database;
    
    //create table version
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        const char *sqlStatement = "CREATE TABLE info (key TEXT DEFAULT '', value TEXT DEFAULT '')";
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, sqlStatement, -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"CREATE TABLE info ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"INSERT INTO info (key,value) VALUES ('version','%@')", databaseVersion];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"INSERT INTO info ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    //create table synchronization
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        const char *sqlStatement = "CREATE TABLE synchronization (timestamp TEXT DEFAULT '', last_sync_status INTEGER DEFAULT '0')";
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, sqlStatement, -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"CREATE TABLE synchronization ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"INSERT INTO synchronization (timestamp,last_sync_status) VALUES ('','0')"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"INSERT INTO synchronization ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    //create table data
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        const char *sqlStatement = "CREATE TABLE data (vid INTEGER, hid INTEGER, varianta TEXT DEFAULT '', varianta_bd TEXT DEFAULT '', homonymie TEXT DEFAULT '', data TEXT DEFAULT '',sortorder INTEGER)";
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, sqlStatement, -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"CREATE TABLE data ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    //create table order
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        const char *sqlStatement = "CREATE TABLE dataorder (id INTEGER, idorder INTEGER)";
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, sqlStatement, -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"CREATE TABLE dataorder ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    //create table css
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        const char *sqlStatement = "CREATE TABLE css (mt_timestamp TEXT DEFAULT '', wt_timestamp TEXT DEFAULT '', tht_timestamp TEXT DEFAULT '', ios_timestamp TEXT DEFAULT '', mt_data TEXT DEFAULT '', wt_data TEXT DEFAULT '', tht_data TEXT DEFAULT '', ios_data TEXT DEFAULT '')";
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, sqlStatement, -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"CREATE TABLE css ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"INSERT INTO css (mt_timestamp,wt_timestamp,tht_timestamp,mt_data,wt_data,tht_data) VALUES ('','','','','','')"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"INSERT INTO css ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (void)deleteDb
{
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    BOOL success;
    NSError *error;
    
    NSFileManager *fileManager = [NSFileManager defaultManager];
    
    success = [fileManager removeItemAtPath:databasePath error:&error];
    
    if(success)
    {
        NSLog(@"DB deleted");
    }
    else
    {
        NSLog(@"DB not deleted");
    }
}

- (BOOL)needFirstSync {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    BOOL need = NO;
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT timestamp FROM synchronization"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                NSString *timestamp = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
                if ([timestamp isEqualToString:@""]) need = YES;
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return need;
}

- (NSString *)getSyncTimestamp {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *timestamp = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT timestamp FROM synchronization"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                timestamp = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return timestamp;
}

- (void)deleteDataWithVid:(long)dataVid {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"DELETE FROM data WHERE vid = '%li'",dataVid];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"DELETE FROM data ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (BOOL)existsDataWithVid:(long)dataVid {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    BOOL exists = NO;
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT 1 FROM data WHERE vid = '%li'",dataVid];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                exists = YES;
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return exists;
}

- (NSString *)getDataWithVid:(long)dataVid {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *data = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT data FROM data WHERE vid = '%li'",dataVid];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                data = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return data;
}

- (void)insertDataWithVid:(long)dataVid Hid:(long)dataHid varianta:(NSString *)dataVarianta variantaBd:(NSString *)dataVariantaBd homonymie:(NSString *)dataHomonymie data:(NSString *)dataData SortOrder:(long)dataSortOrder {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"INSERT INTO data (vid,hid,varianta,varianta_bd,homonymie,data,sortorder) VALUES ('%li','%li','%@','%@','%@','%@','%li')",dataVid,dataHid,dataVarianta,dataVariantaBd,dataHomonymie,[dataData stringByReplacingOccurrencesOfString:@"'" withString:@"''"],dataSortOrder];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"INSERT INTO data ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (void)updateDataWithVid:(long)dataVid Hid:(long)dataHid varianta:(NSString *)dataVarianta variantaBd:(NSString *)dataVariantaBd homonymie:(NSString *)dataHomonymie data:(NSString *)dataData SortOrder:(long)dataSortOrder {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"UPDATE data SET hid = '%li', varianta = '%@',varianta_bd = '%@',homonymie = '%@',data = '%@',sortorder = '%li' WHERE vid = '%li'",dataHid, dataVarianta,dataVariantaBd,dataHomonymie,[dataData stringByReplacingOccurrencesOfString:@"'" withString:@"''"],dataSortOrder,dataVid];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"UPDATE data ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (void)writeSyncTimestamp:(NSString *)timestamp andStatus:(long)status {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"UPDATE synchronization SET timestamp = '%@',last_sync_status = '%li'",timestamp,status];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"UPDATE synchronization ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (void)writeSyncStatus:(long)status {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"UPDATE synchronization SET last_sync_status = '%li'",status];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"UPDATE synchronization ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (NSString *)getCssMtTimestamp {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *timestamp = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT mt_timestamp FROM css"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                timestamp = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return timestamp;
}

- (NSString *)getCssWtTimestamp {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *timestamp = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT wt_timestamp FROM css"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                timestamp = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return timestamp;
}

- (NSString *)getCssThtTimestamp {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *timestamp = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT tht_timestamp FROM css"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                timestamp = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return timestamp;
}

- (NSString *)getCssIosTimestamp {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *timestamp = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT ios_timestamp FROM css"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                timestamp = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return timestamp;
}

- (void)updateCssMtWithTimestamp:(NSString *)timestamp data:(NSString *)data  {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"UPDATE css SET mt_timestamp = '%@', mt_data = '%@'",timestamp,[data stringByReplacingOccurrencesOfString:@"'" withString:@"''"]];        
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"UPDATE css ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare 1");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (void)updateCssWtWithTimestamp:(NSString *)timestamp data:(NSString *)data  {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"UPDATE css SET wt_timestamp = '%@',wt_data = '%@'",timestamp,[data stringByReplacingOccurrencesOfString:@"'" withString:@"''"]];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"UPDATE css ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (void)updateCssThtWithTimestamp:(NSString *)timestamp data:(NSString *)data  {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"UPDATE css SET tht_timestamp = '%@',tht_data = '%@'",timestamp,[data stringByReplacingOccurrencesOfString:@"'" withString:@"''"]];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"UPDATE css ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (void)updateCssIosWithTimestamp:(NSString *)timestamp data:(NSString *)data  {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"UPDATE css SET ios_timestamp = '%@',ios_data = '%@'",timestamp,[data stringByReplacingOccurrencesOfString:@"'" withString:@"''"]];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"UPDATE css ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}


- (NSString *)getCssMtData {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *data = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT mt_data FROM css"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                data = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return data;
}

- (NSString *)getCssWtData {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *data = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT wt_data FROM css"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                data = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return data;
}

- (NSString *)getCssThtData {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *data = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT tht_data FROM css"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                data = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return data;
}

- (NSString *)getCssIosData {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    NSString *data = @"";
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"SELECT ios_data FROM css"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                data = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 0)];
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
    
    return data;
}

- (void)deleteOrder {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        NSString *sqlStatement = [NSString stringWithFormat:@"DELETE FROM dataorder"];
        sqlite3_stmt *compiledStatement;
        if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
            if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                NSLog(@"DELETE FROM dataorder ...");
            } else NSLog(@"Chyba sqlite3_step");
        } else NSLog(@"Chyba sqlite3_prepare");
        sqlite3_finalize(compiledStatement);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

- (void)insertOrder:(NSDictionary *)orderDatas {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    
    sqlite3 *database;
    if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
        sqlite3_exec(database, "BEGIN TRANSACTION", NULL, NULL, NULL);
        long i = 1;
        for (NSDictionary* orderData in orderDatas) {
            long orderDataId = [[orderData objectForKey:@"id"] longValue];
            NSString *sqlStatement = [NSString stringWithFormat:@"INSERT INTO dataorder (id,idorder) VALUES ('%li','%li')",orderDataId,i++];
            sqlite3_stmt *compiledStatement;
            if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
                if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
                    NSLog(@"INSERT INTO dataorder ...");
                } else NSLog(@"Chyba sqlite3_step");
            } else NSLog(@"Chyba sqlite3_prepare");
            sqlite3_finalize(compiledStatement);
        }
        sqlite3_exec(database, "COMMIT TRANSACTION", NULL, NULL, NULL);
        sqlite3_close(database);
    } else NSLog(@"Chyba sqlite3_open");
}

@end
