//
//  ViewController.m
//  Alexis
//
//  Created by Geronimo on 25/11/15.
//  Copyright © 2015 Foxcom. All rights reserved.
//

#import "ViewController.h"
#import "WordWrapper.h"
#import "AppDelegate.h"
#import "sqlite3.h"

@implementation ViewController

#define ROW_HEIGHT 40

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(textDidChange:) name:UITextFieldTextDidChangeNotification object:nil];
    self.wordTable.rowHeight = ROW_HEIGHT;
    wordsArray = [[NSMutableArray alloc]init];
    [self.wordView setHidden:YES];
    [self.wordWebView loadHTMLString:@"" baseURL:nil];
    UIPinchGestureRecognizer *pgr = [[UIPinchGestureRecognizer alloc] initWithTarget:self action:@selector(handlePinch:)];
    pgr.delegate = self;
    [self.wordWebView addGestureRecognizer:pgr];
    font_size = 100;
}

- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    
    AppDelegate *app = (AppDelegate*)[[UIApplication sharedApplication] delegate];
    
    if ([app needFirstSync]){
        [self  performSegueWithIdentifier:@"FirstSyncSegue" sender:self];
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)searchBeginEditing:(id)sender {
    [self refresh:self.searchTextField.text];
}

- (void)textDidChange:(NSNotification *)note {
    [self refresh:self.searchTextField.text];
}

- (BOOL)textFieldShouldReturn:(UITextField *)theTextField {    
    if (theTextField == self.searchTextField) {
        if ([wordsArray count] == 1) {
            WordWrapper *word = [wordsArray objectAtIndex:0];
            [self showWordWithId:[word getWordId]];
        }
        [self.searchTextField resignFirstResponder];
    }
    return YES;
}

- (BOOL)webView:(UIWebView*)webView shouldStartLoadWithRequest:(NSURLRequest*)request navigationType:(UIWebViewNavigationType)navigationType {
    
    NSURL *url = [request URL];
    if ([[url absoluteString] rangeOfString:@"print_heslo"].location != NSNotFound ) {
        NSRange range_1 = [[url absoluteString] rangeOfString:@"("];
        NSRange range_2 = [[url absoluteString] rangeOfString:@")"];
        NSString *word_id = [[url absoluteString] substringWithRange:NSMakeRange (range_1.location + 1, range_2.location - range_1.location - 1)];
        [self showWordWithId:[word_id integerValue]];
    }    
    return YES;
}

- (void)refresh:(NSString *)text {
    NSArray *documentPaths = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSUserDomainMask, YES);
    NSString *documentsDir = [documentPaths objectAtIndex:0];
    NSString *databasePath = [documentsDir stringByAppendingPathComponent:databaseName];
    sqlite3 *database;
    
    [wordsArray removeAllObjects];
    /*
    NSString *search_text = @"";
    NSString *upr_text = [NSString stringWithString:[text lowercaseString]];
    for (NSInteger i=0; i<upr_text.length; i++) {
        NSString *pismeno = [NSString stringWithFormat:@"%C",[[text lowercaseString] characterAtIndex:i]];
        if ([pismeno isEqualToString:@"a"]) {
            search_text = [NSString stringWithFormat:@"%@[aAáÁ]",search_text];
        } else if ([pismeno isEqualToString:@"c"]) {
            search_text = [NSString stringWithFormat:@"%@[cCčČ]",search_text];
        } else if ([pismeno isEqualToString:@"d"]) {
            search_text = [NSString stringWithFormat:@"%@[dDďĎ]",search_text];
        } else if ([pismeno isEqualToString:@"e"]) {
            search_text = [NSString stringWithFormat:@"%@[eEéÉěĚ]",search_text];
        } else if ([pismeno isEqualToString:@"i"]) {
            search_text = [NSString stringWithFormat:@"%@[iIíÍ]",search_text];
        } else if ([pismeno isEqualToString:@"n"]) {
            search_text = [NSString stringWithFormat:@"%@[nNňŇ]",search_text];
        } else if ([pismeno isEqualToString:@"o"]) {
            search_text = [NSString stringWithFormat:@"%@[oOóÓ]",search_text];
        } else if ([pismeno isEqualToString:@"r"]) {
            search_text = [NSString stringWithFormat:@"%@[rRřŘ]",search_text];
        } else if ([pismeno isEqualToString:@"s"]) {
            search_text = [NSString stringWithFormat:@"%@[sSšŠ]",search_text];
        } else if ([pismeno isEqualToString:@"t"]) {
            search_text = [NSString stringWithFormat:@"%@[tTťŤ]",search_text];
        } else if ([pismeno isEqualToString:@"u"]) {
            search_text = [NSString stringWithFormat:@"%@[uUúÚůŮ]",search_text];
        } else if ([pismeno isEqualToString:@"y"]) {
            search_text = [NSString stringWithFormat:@"%@[yYýÝ]",search_text];
        } else if ([pismeno isEqualToString:@"z"]) {
            search_text = [NSString stringWithFormat:@"%@[zZžŽ]",search_text];
        } else {
            search_text = [NSString stringWithFormat:@"%@[%@%@]",search_text,pismeno,[pismeno uppercaseString]];
        }
    }
    
    */
    if (![text isEqualToString:@""]) {
        if(sqlite3_open([databasePath UTF8String], &database) == SQLITE_OK) {
            //NSString *sqlStatement = [NSString stringWithFormat:@"SELECT id,varianta FROM data WHERE varianta LIKE '%@%%'",text];
            //NSString *sqlStatement = [NSString stringWithFormat:@"SELECT id,varianta,homonymie FROM data WHERE varianta GLOB '*%@*'",search_text];
            NSString *sqlStatement = [NSString stringWithFormat:@"SELECT vid,varianta,homonymie,sortorder,idorder FROM data LEFT JOIN dataorder ON dataorder.id = data.hid WHERE hid IN (SELECT DISTINCT hid FROM data WHERE varianta LIKE '%@%%' OR varianta_bd LIKE '%@%%') ORDER BY idorder,sortorder",text,text];
            sqlite3_stmt *compiledStatement;
            if(sqlite3_prepare_v2(database, [sqlStatement UTF8String], -1, &compiledStatement, NULL) == SQLITE_OK) {
                while(sqlite3_step(compiledStatement) == SQLITE_ROW) {
                    long param1 = sqlite3_column_int(compiledStatement, 0);                    
                    NSString *param2 = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 1)];
                    NSString *param3 = [NSString stringWithUTF8String: (char *)sqlite3_column_text(compiledStatement, 2)];
                    long param4 = sqlite3_column_int(compiledStatement, 3);                    
                    if (![param3 isEqualToString:@""]) param2 = [NSString stringWithFormat:@"%@ %@",param2,param3];
                    if (param4 > 1) param2 = [NSString stringWithFormat:@"  %@",param2];
                    WordWrapper *word = [[WordWrapper alloc]initWithWord:param2 wId:param1];
                    [wordsArray addObject:word];
                    [self.wordView setHidden:NO];
                }
            } else NSLog(@"Chyba sqlite3_prepare");
            sqlite3_finalize(compiledStatement);
            sqlite3_close(database);
        } else NSLog(@"Chyba sqlite3_open");
    } else {
        [self.wordView setHidden:YES];
    }
    /*
    wordsArray = [NSMutableArray arrayWithArray:[wordsArray sortedArrayUsingComparator:^NSComparisonResult(id a, id b) {
        NSString *first = [(WordWrapper*)a getWordText];
        NSString *second = [(WordWrapper*)b getWordText];
        NSComparisonResult result =  [first compare:second];
        return  result;
    }]];*/
        
    [self.wordTable reloadData];
    [self.wordTable setContentOffset:CGPointMake(0.0, 0.0)];
}

-(void)tableView:(UITableView *)tableView willDisplayCell:(UITableViewCell *)cell forRowAtIndexPath:(NSIndexPath *)indexPath{
    if ([tableView respondsToSelector:@selector(setSeparatorInset:)]) {
        [tableView setSeparatorInset:UIEdgeInsetsZero];
    }
    if ([tableView respondsToSelector:@selector(setLayoutMargins:)]) {
        [tableView setLayoutMargins:UIEdgeInsetsZero];
    }
    if ([tableView respondsToSelector:@selector(setLayoutMargins:)]) {
        cell.preservesSuperviewLayoutMargins = NO;
        [cell setLayoutMargins:UIEdgeInsetsZero];
    }
    if ([cell respondsToSelector:@selector(setSeparatorInset:)]){
        [cell setSeparatorInset:UIEdgeInsetsZero];
    }
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [wordsArray count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *simpleTableIdentifier = @"wordCell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:simpleTableIdentifier];
    
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:simpleTableIdentifier];
    }
    
    cell.textLabel.text = [[wordsArray objectAtIndex:indexPath.row] getWordText];
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    WordWrapper *word = [wordsArray objectAtIndex:indexPath.row];
    
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    
    [self showWordWithId:[word getWordId]];
}

- (void)showWordWithId:(long)word_id {
    [self.searchTextField resignFirstResponder];
    
    [self.wordView setHidden:YES];
    
    AppDelegate *app = (AppDelegate*)[[UIApplication sharedApplication] delegate];
    NSString *pomstr1 = @"<html><head><style type=""text/css"">";
    NSString *pomstr2 = @"</style></head><body style=""min-width:0;"">";
    NSString *pomstr3 = @"</body></html>";
    NSString *str1 = [app getCssMtData];
    NSString *str2 = [app getCssWtData];
    NSString *str3 = [app getCssThtData];
    NSString *str35 = [app getCssIosData];    
    //NSString *str35 = @".vyznam_wrapper, .pripoj_wrapper{text-indent:-1.2em; padding-left:1.2em;} .varianta-tvarChar-koncovka-tvar{white-space:nowrap;} .ext_pozn{display:inline-block;margin-top:0.4em;}";    
    NSString *str4 = [app getDataWithVid:word_id];    
    str4 = [str4 stringByReplacingOccurrencesOfString:@"javascript:" withString:@""];
    NSString *str = [NSString stringWithFormat:@"%@%@%@%@%@%@%@%@",pomstr1,str1,str2,str3,str35,pomstr2,str4,pomstr3];
    [self.wordWebView loadHTMLString:str baseURL:nil];
}

- (void)webViewDidFinishLoad:(UIWebView *)webView
{
    NSString *jsString = [[NSString alloc] initWithFormat:@"document.getElementsByTagName('body')[0].style.webkitTextSizeAdjust= '%f%%'", font_size];
    [self.wordWebView stringByEvaluatingJavaScriptFromString:jsString];
}

- (void)handlePinch:(UIPinchGestureRecognizer *)gesture
{
    if (gesture.state == UIGestureRecognizerStateChanged) {
        //NSLog(@"gesture.scale = %f", gesture.scale);
        temp_size = round((gesture.scale*font_size)/20)*20;
        //NSLog(@"gesture.scale = %f", temp_size);        
        if (temp_size < 100) {
            temp_size = 100;
        }
        if (temp_size > 240) {
            temp_size = 240;
        }
        NSString *jsString = [[NSString alloc] initWithFormat:@"document.getElementsByTagName('body')[0].style.webkitTextSizeAdjust= '%f%%'", temp_size];
        [self.wordWebView stringByEvaluatingJavaScriptFromString:jsString];
    }
    
    if (gesture.state == UIGestureRecognizerStateEnded) {
        font_size = temp_size;
        NSString *jsString = [[NSString alloc] initWithFormat:@"document.getElementsByTagName('body')[0].style.webkitTextSizeAdjust= '%f%%'", font_size];
        [self.wordWebView stringByEvaluatingJavaScriptFromString:jsString];
    }

}

@end
